@@ -18,7 +18,8 @@ import click
 from lxml import etree
 
 
-default_rulesets = ["various", "quotes", "ligatures_consonantal", "roman_digits", "uvius", "punctuation", "spaces"]
+default_rulesets = ["various", "quotes", "ligatures_consonantal", "ligatures_vocal", "roman_digits", "uvius",
+                    "punctuation", "spaces"]
 
 
 @click.command("regularize",
@@ -93,3 +94,7 @@ def collect_default_rulesets(remove_default: List[str], add_default: List[str],
         rules.append(r)
 
     return rules
+
+
+if __name__ == "__main__":
+    regularize_cli()
